-------------------------------------------------------------------------------
--
-- Title	: 8b/10b Encoder
-- Design	: 8-bit to 10-bit Encoder
-- Project	: 8000 - 8b10b_encdec
-- Author	: Ken Boyette
-- Company	: Critia Computer, Inc.
--
-------------------------------------------------------------------------------
--
-- File			: 8b10b_enc.vhd
-- Version		: 1.0
-- Generated	: 09.15.2006
-- By			: Itf2Vhdl ver. 1.20
--
-------------------------------------------------------------------------------
--
-- Description :
--	This module provides 8-bit to 10-bit encoding.
--	It accepts 8-bit parallel data input and generates 10-bit encoded data
--	output in accordance with the 8b/10b standard.  This coding method was
--	described in the 1983 IBM publication "A DC-Balanced, Partitioned-Block,
--	8B/10B Transmission Code" by A.X. Widmer and P.A. Franaszek and was granted
--	a U.S. Patent #4,486,739 in 1984 which has now expired.
--
--		The parallel 8-bit Binary input represent 256 possible values, called
--		characters.
--		The bits are identified as:
--			HI, GI, FI, EI, DI, CI, BI, AI (Most Significant to Least)
--		The	output is a 10-bit encoded character whose bits are identified as:
--			AO, BO, CO, DO, EO, IO, FO, GO, HO, JO (Least Significant to Most)
--		An additional 12 output characters, K, are defined for command and
--		synchronization use.
--		KI, is used to indicate that the input is for a special character.
--		All inputs and outputs are synchronous with an externally supplied
--		byte rate clock BYTECLK.
--		The encoded output is valid one clock after the input.
--		There is a reset input, RESET, to reset the logic.  The next rising 
--		BYTECLK after RESET is deasserted latches valid input data.
--
--		Note: This VHDL structure closely follows the discrete logic defined 
--		in the original article and the subsequent patent.
--		The Figures referenced are those in the patent.
-------------------------------------------------------------------------------
--		This program is licensed under the GPL.
-------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.all;

entity enc_8b10b_wrapper is	
	port
	(
		reset_i 	: in 	std_logic ;							-- Global asynchronous reset (active high) 
		clk_i 	: in 	std_logic ;							-- Master synchronous send byte clock
		strobe_i 	: in 	std_logic ;							-- Master synchronous send byte clock
		k_i		: in 	std_logic ;							-- Control (K) input(active high)
		data_i	: in 	std_logic_vector(7 downto 0);	-- Unencoded input data
		data_o	: out std_logic_vector(9 downto 0) 	-- Encoded out 
	);
end enc_8b10b_wrapper;

architecture wrap of enc_8b10b_wrapper is

begin
	
	enc: entity work.enc_8b10b
   port map
	(
		RESET 	=> reset_i,
		SBYTECLK => clk_i,
		strobe => strobe_i,
		KI 		=> k_i,
		AI			=> data_i(0),
		BI			=> data_i(1),
		CI			=> data_i(2),
		DI			=> data_i(3),	
		EI			=> data_i(4),	
		FI			=> data_i(5),
		GI			=> data_i(6),
		HI			=> data_i(7),
		AO			=> data_o(0),
		BO       => data_o(1),
		CO       => data_o(2),
		DO       => data_o(3),
		EO       => data_o(4),
		IO       => data_o(5),
		FO       => data_o(6),
		GO       => data_o(7),
		HO			=> data_o(8),
		JO       => data_o(9)
	);
				
end wrap;

